/* @override http://localhost:8000/static/css/coop_bar.css */

/* */


.aloha-sidebar-handle{
    display: none;
}

#coop-bar {
	position: fixed;
	top: 10px;
	width: 160px;
	font-weight: lighter;
	-webkit-border-radius: 4px;
-moz-border-radius: 4px;
border-radius: 4px;
-webkit-box-shadow: #666 0px 2px 3px;
-moz-box-shadow: #666 0px 2px 3px;
box-shadow: #555 0px 2px 5px;
background: #FFFFFF;
background: -webkit-gradient(linear, 0 0, 0 bottom, from(#FFFFFF), to(#ABABAB));
background: -webkit-linear-gradient(#FFFFFF, #ABABAB);
background: -moz-linear-gradient(#FFFFFF, #ABABAB);
background: -ms-linear-gradient(#FFFFFF, #ABABAB);
background: -o-linear-gradient(#FFFFFF, #ABABAB);
background: linear-gradient(#FFFFFF, #ABABAB);
	padding: 20px 15px;
	right: 10px;
	text-align: left;
	z-index: 99999;
	font: 12px Tahoma, Arial,"Trebuchet MS", Trebuchet;
		cursor: move;

}


#coop-bar a {
    text-decoration: none;
	font-weight: bold;
	display: block;
	position: relative;
	padding-top: 3px;
	padding-bottom: 3px;
	color: #565656;
	border: 1px solid rgba(255,255,255,0);
	-webkit-border-radius: 4px;
	-moz-border-radius: 4px;
	border-radius: 4px;

}

#coop-bar-status{
	margin-top: 10px;
	font-weight: bold;
}


#coop-bar a:hover {
	border: 1px solid #fff;
	background-color: rgba(255,255,255,0.5);
	color: #3b416d;
	box-shadow: #777 0 0 7px;
}

#coop-bar .separator {
	margin: 4px 0 4px 0;
	width: 100%;
	border: 1px solid #9b9c9c;
	border-bottom-style: solid;
	border-bottom-color: #e6e6e6;
}

 .icon { padding-left: 23px; background-repeat: no-repeat;
	background-position: 2px 2px;
}



/*
    HUMANIZED MESSAGES 1.0
    idea - http://www.humanized.com/weblog/2006/09/11/monolog_boxes_and_transparent_messages
    home - http://humanmsg.googlecode.com
*/


.humanMsg {
    letter-spacing: -1px;
    position: fixed;
    top: 130px;
    left: 25%;
    width: 50%;
    color: white;
    text-align: center;
    display: none;
    opacity: 0;
    z-index: 100000;
    font: bold 24px/50px "Trebuchet MS", Trebuchet, Tahoma, Arial;
-webkit-border-radius: 9px;
-moz-border-radius: 9px;
border-radius: 9px;
-moz-box-shadow: 3px 3px 5px #888;
-webkit-box-shadow: 3px 3px 5px #888;
box-shadow: 3px 3px 5px #888;
}

div.humanMsg.success {
    background-color: #4b8331;
}

div.humanMsg.error {
    background-color: #99332d;
}


.humanMsg p {
    padding: .3em;
    display: inline;
    }

.humanMsg a {
    display: none;
    }

#humanMsgLog {
    font: normal 10px Helvetica, Arial, Sans-Serif;
    color: white;
    position: fixed;
    bottom: 0;
    max-height: 200px;
	right: 0;
	left: 0;
}

#humanMsgLog p {
    /* by default not displayed */
    display: none;
    position: relative;
    width: 70px;
    margin: 0;
    padding: 0 10px;
    line-height: 20px;
    background: #4b8331;
    text-align: center;
    white-space: pre;
    cursor: pointer;
    color: white;
	font-weight: bold;
	font-size: 10px;
	left: 25px;

-webkit-border-top-left-radius: 5px;
-webkit-border-top-right-radius: 5px;
-moz-border-radius-topleft: 5px;
-moz-border-radius-topright: 5px;
border-top-left-radius: 5px;
border-top-right-radius: 5px;

}

#humanMsgLog p:hover {
    background: #63a47a;
	text-decoration: underline;
}

#humanMsgLog ul {
    background: #eee url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAUAAAARCAIAAACaSvE/AAAAGXRFWHRTb2Z0d2FyZQBBZG9iZSBJbWFnZVJlYWR5ccllPAAAAE1JREFUeNqEjVEKACAIQ516Ee//5wVNCjIjaB/iY5vC3YkoIgDkVDOjQ5pqLCI3r2bLFzNzyydvM4uKqfJPKN4vyl9LO/7o3/6PhwADAIWkFPjc5eRrAAAAAElFTkSuQmCC) repeat-x;
    margin: 0;
    padding: 0;
    position: relative;
    max-height: 180px;
    overflow: auto;
    display: none;
    }

#humanMsgLog ul li {
    color: #555;
    font-size: 12px;
    list-style-type: none;
    border-bottom: 1px solid #ddd;
    line-height: 40px;
    display: none;
    padding: 0 20px;
    position: relative;
    overflow: hidden;
    white-space: pre;
    }

#humanMsgLog ul li:hover {
    background: #f2f2f2;
    }

#humanMsgLog ul li:first-child {
    margin-top: 1px;
    }

#humanMsgLog ul li .error {
    color: orangered;
    }

#humanMsgLog ul li .indent {
    position: absolute;
    top: 0;
    left: 100px;
    margin-right: 200px;
    height: inherit;
    }